==> haskell-resource-pool-0.2.3.2-66-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-Cn2GMsC92ex3VlpOWJbAmC
key: resource-pool-0.2.3.2-Cn2GMsC92ex3VlpOWJbAmC
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
abi: af34f3be32d63ef856ee71c3c31cabc7
exposed: True
exposed-modules:
    Data.Pool
import-dirs: /usr/lib/ghc-8.6.5/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-Cn2GMsC92ex3VlpOWJbAmC
depends:
    base-4.12.0.0 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    monad-control-1.0.2.3-FeYEsm8P5694VImLZDBXYS stm-2.5.0.0
    time-1.8.0.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-HGTy7PtJMWjITFSZBfRdND
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-Izm1bBgNWskL8UksUeZEhR
key: resource-pool-0.2.3.2-Izm1bBgNWskL8UksUeZEhR
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
abi: e572237deefcf51e1906f218b2784519
exposed: True
exposed-modules:
    Data.Pool
import-dirs: /usr/lib/ghc-8.6.5/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-Izm1bBgNWskL8UksUeZEhR
depends:
    base-4.12.0.0 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    monad-control-1.0.2.3-HrYPbjEu44jLedbHP7C2CP stm-2.5.0.0
    time-1.8.0.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-AKjzOvjUCFd4YE2ZLG0MGC
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
